/* Package name/version */
#undef PACKAGE
#undef VERSION

/* lavtools locations */
#undef LAVPLAY_LOCATION
#undef LAVREC_LOCATION
#undef LAV2YUV_LOCATION
#undef LAV2WAV_LOCATION
#undef MP2ENC_LOCATION
#undef MPEG2ENC_LOCATION
#undef YUVSCALER_LOCATION
#undef YUVDENOISE_LOCATION
#undef MPLEX_LOCATION
#undef LAVTRANS_LOCATION
#undef YUVPLAY_LOCATION
#undef YUV2LAV_LOCATION
#undef LAVPIPE_LOCATION
#undef LAVADDWAV_LOCATION
#undef YUV2DIVX_LOCATION

/* mixer, video and audio devices */
#undef DEFAULT_MIXER
#undef DEFAULT_VIDEO
#undef DEFAULT_AUDIO

/* Define us to use OSS/ALSA */
#undef OSS
#undef ALSA

/* Have lirc? */
#undef HAVE_LIRC

/* png/jpeg support */
#undef HAVE_JPEG
#undef HAVE_PNG
